# nasse/tui

The Terminal UI apps available with Nasse.

## HTTP

The HTTP app lets you test endpoints easily and intuitively.

### Installation

To following steps lets you prepare everything to test the app :

1. Install the requirements
   1. Open this directory in your terminal
   2. Enter `pip install -r requirements.txt`
2. Install Nasse
   1. Open the project root directory in your terminal
   2. Enter `pip install .`
3. Open the TUI
   1. Open the project root directory in your terminal
   2. Enter `python nasse/tui/apps/http.nasse.py`
